**pjz** 😴👕👖💤: Photonics on JAX
==================================

`pjz <https://www.github.com/spinsphotonics/pjz>`_ is 
`JAX <https://www.github.com/google/jax>`_ and 
`fdtd-z <https://www.github.com/spinsphotonics/fdtdz>`_, 
a set of tools for runnning photonic simulation and optimization workflows at
scale.

.. currentmodule:: pjz

.. automodule:: pjz

Main API
--------

.. autoclass:: SimParams
.. autofunction:: field
.. autofunction:: scatter 
.. autofunction:: mode
.. autofunction:: epsilon
.. autofunction:: density 


Shape functions
---------------

.. autofunction:: rect
.. autofunction:: circ 
.. autofunction:: invert 
.. autofunction:: union
.. autofunction:: intersect
.. autofunction:: dilate
.. autofunction:: shift


